diff --git a/TShockAPI/TShock.cs b/TShockAPI/TShock.cs
index 046f274c..9679a032 100755
--- a/TShockAPI/TShock.cs
+++ b/TShockAPI/TShock.cs
@@ -1030,7 +1030,7 @@ namespace TShockAPI
player.PaintThreshold = 0;
}
- if (player.HealOtherThreshold > TShock.Config.HealOtherThreshold)
+ if (player.HealOtherThreshold >= TShock.Config.HealOtherThreshold)
{
player.Disable("Reached HealOtherPlayer threshold", flags);
}
diff --git a/TShockAPI/ConfigFile.cs b/TShockAPI/ConfigFile.cs
index 2b9466ca..ad4b43b0 100755
--- a/TShockAPI/ConfigFile.cs
+++ b/TShockAPI/ConfigFile.cs
@@ -295,8 +295,8 @@ namespace TShockAPI
[Description("Disable a player if this number of projectiles is created within 1 second.")]
public int ProjectileThreshold = 50;
- /// ProjectileThreshold - Disables a player if this number of projectiles is created within 1 second.
- [Description("Disable a player if this number of projectiles is created within 1 second.")]
+ /// HealOtherThreshold - Disables a player if this number of HealOtherPlayer packets is sent within 1 second.
+ [Description("Disables a player if this number of HealOtherPlayer packets is sent within 1 second.")]
public int HealOtherThreshold = 50;
/// ProjIgnoreShrapnel - Whether or not to ignore shrapnel from crystal bullets for the projectile threshold count.